@@ -9,7 +9,7 @@
 # 
 package Config::Model::Tk::HashEditor ;
 BEGIN {
-  $Config::Model::Tk::HashEditor::VERSION = '1.313';
+  $Config::Model::Tk::HashEditor::VERSION = '1.314';
 }
 
 use strict;
@@ -273,7 +273,7 @@ sub add_entry {
 
     if ($@) {
 	$cw -> Dialog ( -title => 'Hash index error',
-			-text  => $@,
+			-text  => $@->as_string,
 		      )
 	  -> Show ;
 	return 0 ;
@@ -504,7 +504,7 @@ sub store {
 
     if ($@) {
 	$cw -> Dialog ( -title => 'Value error',
-			-text  => $@,
+			-text  => $@ -> as_string,
 		      )
             -> Show ;
 	$cw->reset_value ;
