@@ -9,7 +9,7 @@
 # 
 package Config::Model::Tk::LeafEditor ;
 BEGIN {
-  $Config::Model::Tk::LeafEditor::VERSION = '1.313';
+  $Config::Model::Tk::LeafEditor::VERSION = '1.314';
 }
 
 use strict;
@@ -45,14 +45,12 @@ sub Populate {
     $cw->{store_cb} = delete $args->{-store_cb} || die __PACKAGE__,"no -store_cb" ;
 
     my $inst = $leaf->instance ;
-    $inst->push_no_value_check('fetch') ;
-
     my $vt = $leaf -> value_type ;
     $logger->info("Creating leaf editor for value_type $vt");
 
     $cw->add_header(Edit => $leaf)->pack(@fx) ;
 
-    $cw->{value} = $leaf->fetch ;
+    $cw->{value} = $leaf->fetch ( check => 'no');
     my $vref = \$cw->{value};
 
     my @pack_args = @fx ;
@@ -108,8 +106,6 @@ sub Populate {
 
     }
 
-    $inst->pop_no_value_check ;
-
     $cw->ConfigModelNoteEditor( -object => $leaf )->pack;
     $cw->add_warning($leaf)->pack(@fx) ;
     $cw->add_info_button()->pack( @fx,qw/-anchor n/) ;
@@ -207,7 +203,7 @@ sub delete {
 
     if ($@) {
         $cw -> Dialog ( -title => 'Delete error',
-                        -text  => "$@",
+                        -text  => $@->as_string,
                       )
             -> Show ;
     }
@@ -230,7 +226,7 @@ sub store {
 
     if ($@) {
         $cw -> Dialog ( -title => 'Value error',
-                        -text  => "$@",
+                        -text  => $@->as_string,
                       )
             -> Show ;
         $cw->reset_value ;
@@ -255,7 +251,7 @@ sub set_value_help {
 
 sub reset_value {
     my $cw = shift ;
-    $cw->{value} = $cw->{leaf}->fetch ;
+    $cw->{value} = $cw->{leaf}->fetch (check => 'no') ;
     if (defined $cw->{e_widget}) {
         $cw->{e_widget}->delete('1.0','end') ;
         $cw->{e_widget}->insert('end',$cw->{value},'value') ;
