@@ -9,7 +9,7 @@
 # 
 package Config::Model::Tk::LeafViewer ;
 BEGIN {
-  $Config::Model::Tk::LeafViewer::VERSION = '1.313';
+  $Config::Model::Tk::LeafViewer::VERSION = '1.314';
 }
 
 use strict;
@@ -43,13 +43,10 @@ sub Populate {
       || die "LeafViewer: no -path, got ",keys %$args;
 
     my $inst = $leaf->instance ;
-    $inst->push_no_value_check('fetch') ;
 
     my $vt = $leaf -> value_type ;
     $logger->info("Creating leaf viewer for value_type $vt");
-    my $v = $leaf->fetch ;
-
-    $inst->pop_no_value_check ;
+    my $v = $leaf->fetch( check => 'no' ) ;
 
     $cw->add_header(View => $leaf)->pack(@fx) ;
 
@@ -125,7 +122,7 @@ sub get_info {
     my $m = $leaf->mandatory ;
     push @items, "is mandatory: ".($m ? 'yes':'no') if defined $m;
 
-    foreach my $what (qw/min max warn_if_match warn_unless_match warn/) {
+    foreach my $what (qw/min max warn_if_match warn_unless_match warn grammar/) {
 	my $v = $leaf->$what() ;
 	push @items, "$what value: $v" if defined $v;
     }
