@@ -9,7 +9,7 @@
 # 
 package Config::Model::Tk::NodeEditor ;
 BEGIN {
-  $Config::Model::Tk::NodeEditor::VERSION = '1.313';
+  $Config::Model::Tk::NodeEditor::VERSION = '1.314';
 }
 
 use strict;
@@ -152,7 +152,7 @@ sub fill_pane {
 		    -command => $edit_sub) ;
 	$edb -> pack(-anchor => 'w');
 
-	my $content = $type eq 'leaf' ? $obj->fetch_no_check || ''
+	my $content = $type eq 'leaf' ? $obj->fetch( check => 'no') || ''
 	            : $type eq 'node' ? $node->config_class_name
 	            :                   $type ;
  	$cw->Balloon(-state => 'balloon') 
