@@ -11,7 +11,7 @@
 
 package Config::Model::TkUI ;
 BEGIN {
-  $Config::Model::TkUI::VERSION = '1.313';
+  $Config::Model::TkUI::VERSION = '1.314';
 }
 
 use strict;
@@ -31,8 +31,6 @@ use Tk::Photo ;
 use Tk::PNG ; # required for Tk::Photo to be able to load pngs
 use Tk::DialogBox ;
 
-require Tk::ErrorDialog;
-
 use Config::Model::Tk::LeafEditor ;
 use Config::Model::Tk::CheckListEditor ;
 
@@ -62,6 +60,19 @@ $icon_path .= 'Tk/icons/' ;
 
 my $logger = Log::Log4perl::get_logger(__PACKAGE__);
 
+no warnings "redefine" ;
+
+sub Tk::Error {
+    my ($cw,$error,@locations) = @_;
+    my $msg = ref($error) ? $error->as_string : $error ;
+    $msg .= "stack: \n@locations\n";
+    $cw -> Dialog ( -title => 'Config::Model error',
+                    -text  => $msg,
+                  ) ;
+}
+
+use warnings "redefine" ;
+
 sub ClassInit {
     my ($class, $mw) = @_;
     # ClassInit is often used to define bindings and/or other
@@ -404,7 +415,7 @@ sub save {
 	eval { $cw->{root}->instance->write_back(@wb_args); } ;
 	if ($@) {
 	  $cw -> Dialog ( -title => 'Save error',
-			  -text  => "$@",
+			  -text  => $@->as_string,
 			)
             -> Show ;
 	}
@@ -629,6 +640,17 @@ sub disp_hash {
 
     my $node_loc = $node->location ;
 
+    # need to keep track myself of previous sibling as 
+    # $tkt->entrycget($path,'-after') dies
+    # and $tkt->info('prev',$path) return the path above in the displayed tree, which
+    # is not necessarily a sibling :-(
+    my $prev_sibling = '';
+    my %tk_previous_path ;
+    foreach ($tkt->info('children', $path )) {
+	$tk_previous_path{$_} = $prev_sibling ;
+	$prev_sibling = $_ ;
+    }
+
     my $prevpath = '' ;
     foreach my $idx (@idx) {
 	my $newpath = $path.'.'. to_path($idx) ;
@@ -640,9 +662,8 @@ sub disp_hash {
 	my $sub_elt =  $elt->fetch_with_id($idx) ;
 
 	# check for display order mismatch
-	if ($tkt->infoExists($newpath) and $prevpath) {
-	    my $tkprevpath = $tkt->info( prev => $newpath );
-	    if ($prevpath ne $tkprevpath) {
+	if ($tkt->infoExists($newpath)) {
+	    if ($prevpath ne $tk_previous_path{$newpath}) {
 		$logger->trace("disp_hash deleting mismatching $newpath mode $eltmode cargo_type $elt_type" );
 		$tkt->delete(entry => $newpath) ;
 	    }
@@ -773,7 +794,7 @@ sub disp_leaf {
     $logger->trace( "disp_leaf    path is $path" );
 
     my $std_v = $leaf_object->fetch('standard') ;
-    my $value = $leaf_object->fetch_no_check ;
+    my $value = $leaf_object->fetch(check => 'no', silent => 1) ;
     my $tkt = $cw->{tktree} ;
 
     my $img ;
